Changelog of threedidepth
=========================


0.7.2 (2025-10-03)
------------------

- Add timestamps to band descriptions.


0.7.1 (2025-09-24)
------------------

- Keep old mode constants available for backwards compatibility.


0.7.0 (2025-09-23)
------------------

- Add support for water quality results.


0.6.3 (2024-03-22)
------------------

- Fix no_data_value is undefined.


0.6.2 (2024-03-14)
------------------

- Assign a default value if no_data_value is undefined.


0.6.1 (2023-07-11)
------------------

- Add release action for automatic upload to GitHub and PyPI.


0.6.0 (2023-07-10)
------------------

- Update dependency versions
- Add support for calculating maximum waterlevel as well as per timestep.


0.5 (2021-07-02)
----------------

- Added support for result type 'aggregate'.

- Got rid of NetCDF4 dependency by using h5netcdf.

- Fix coordinates of NetCDF output. (#17)


0.4 (2021-03-23)
----------------

- Enabled multiple calculation steps.

- Added netCDF output option.


0.3 (2021-02-10)
----------------

- Reorder to match the lizard triangulation.


0.2 (2020-12-10)
----------------

- Implemented lizard method and set it as default.


0.1.2 (2020-09-21)
------------------

- Fix off-by-one-pixel nodgrid.


0.1.1 (2020-09-11)
------------------

- Fix flipped nodgrid.


0.1 (2020-09-03)
----------------

- First version.
